--[[---------------------------------------------------------------------------------
  MyACEPercentage - Originally by Instant.  Upgraded to Ace3 (ManaPerc) by phyber
------------------------------------------------------------------------------------]]
local ManaPerc = LibStub("AceAddon-3.0"):NewAddon("ManaPerc", "AceHook-3.0", "AceConsole-3.0")
-- Default options
local defaults = {
	profile = {
		current = false,
		total = true,
		colour = true,
	},
}
-- Locale
local L = LibStub("AceLocale-3.0"):GetLocale("ManaPerc")
-- Some local functions/values
local sformat = string.format
local GetSpellInfo = GetSpellInfo
local UnitMana = UnitMana
local UnitManaMax = UnitManaMax
local MANA_COST = MANA_COST
-- Our SV DB, we'll fill this in later
local db

-- Return our options table
local function getOptions()
	local options = {
		type = "group",
		name = GetAddOnMetadata("ManaPerc", "Title"),
		args = {
			mpdesc = {
				type = "description",
				order = 0,
				name = GetAddOnMetadata("ManaPerc", "Notes"),
			},
			total = {
				name = L["Show Total"],
				desc = L["TOTAL_DESC"],
				type = "toggle",
				order = 2,
				width = "full",
				get = function() return db.total end,
				set = function() db.total = not db.total end,
			},
			current = {
				name = L["Show Current"],
				desc = L["CURRENT_DESC"],
				type = "toggle",
				order = 3,
				width = "full",
				get = function() return db.current end,
				set = function() db.current = not db.current end,
			},
			colour = {
				name = L["Enable Colour"],
				desc = L["COLOUR_DESC"],
				type = "toggle",
				order = 1,
				width = "full",
				get = function() return db.colour end,
				set = function() db.colour = not db.colour end,
			}
		}
	}
	return options
end

--[[--------------------------------------------------------------------------------
  Addon Enabling/Disabling
-----------------------------------------------------------------------------------]]
function ManaPerc:OnInitialize()
	-- Grab our DB and fill in the 'db' variable
	self.db = LibStub("AceDB-3.0"):New("ManaPercDB", defaults, "Default")
	db = self.db.profile
	-- Register our options
	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("ManaPerc", getOptions)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("ManaPerc", GetAddOnMetadata("ManaPerc", "Title"))
	-- Register chat command to open the options dialog
	self:RegisterChatCommand("manaperc", function() InterfaceOptionsFrame_OpenToFrame(LibStub("AceConfigDialog-3.0").BlizOptions["ManaPerc"].frame) end)
end

function ManaPerc:OnEnable()
	self:HookScript(GameTooltip, "OnTooltipSetSpell", "ProcessOnShow")
end
--[[--------------------------------------------------------------------------------
  Main Processing
-----------------------------------------------------------------------------------]]
function ManaPerc:ProcessOnShow(tt, ...)
	-- Get the name of the spell along with the cost and power type.
	local name = tt:GetSpell()
	local _, _, _, cost, _, ptype = GetSpellInfo(name)
	-- If the spell costs something and is a Mana using spell...
	-- We must check that they're not nil here too, due to Blizzard
	-- doing something funky when setting Talents in the tooltip.
	if cost and ptype and cost > 0 and ptype == 0 then
		local dttext, dctext = "", ""
		-- Work out the percentage vs. the players total mana
		if db.total  then
			local ttext = sformat("%.1f", cost / (UnitManaMax('player') / 100))
			if db.colour then
				dttext = " |cFFFFFF00("..ttext.."%)"			
			else
				dttext = " (t:"..ttext.."%)"
			end
		end
		-- Work out the percentage vs. the players current mana
		if db.current  then
			local ctext = sformat("%.1f", cost / (UnitMana('player') / 100))
			if db.colour then
				dctext = " |cFF00FF00("..ctext.."%)"
			else
				dctext = " (c:"..ctext.."%)"
			end
		end
		-- Add the new information to the tooltip
		GameTooltipTextLeft2:SetText(sformat(MANA_COST, cost)..dctext..dttext)
	end
	-- Call the original function
	self.hooks[GameTooltip]["OnTooltipSetSpell"](tt, ...)
end
